# PERF01-BP04: Use policies or reference architectures

## Description

Use standardized patterns để ensure consistency.

## Implementation Guidance

- Adopt cloud provider reference architectures
- Create internal architecture standards
- Define approved technology list
- Implement architecture governance
- Review and update standards regularly

## Risk Level

Low - Non-standard architectures are harder to support.

## Related Best Practices

- [PERF01-BP05](PERF01-BP05-Cloud-Provider-Guidance.md)
- [OPS05-BP06](../../01-OPS/OPS05-Prepare-Development-And-Integration/OPS05-BP06-Share-Design-Standards.md)
